@@ -4,18 +4,16 @@
  *	  POSTGRES index valid attribute bit map definitions.
  *
  *
- * Portions Copyright (c) 1996-2000, PostgreSQL, Inc
+ * Portions Copyright (c) 1996-2005, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: ibit.h,v 1.13 2000/04/12 17:16:26 momjian Exp $
+ * $PostgreSQL: pgsql/src/include/access/ibit.h,v 1.23 2004/12/31 22:03:21 pgsql Exp $
  *
  *-------------------------------------------------------------------------
  */
 #ifndef IBIT_H
 #define IBIT_H
 
-#include "catalog/pg_index.h"
-
 typedef struct IndexAttributeBitMapData
 {
 	bits8		bits[(INDEX_MAX_KEYS + 8 - 1) / 8];
@@ -31,4 +29,4 @@ typedef IndexAttributeBitMapData *IndexAttributeBitMap;
  */
 #define IndexAttributeBitMapIsValid(bits) PointerIsValid(bits)
 
-#endif	 /* IBIT_H */
+#endif   /* IBIT_H */
